@@ -9,7 +9,7 @@ use PDL::VectorValued;
 use PDL;
 use strict;
 
-our $VERSION = '1.23.0'; ##-- update with perl-reversion from Perl::Version module
+our $VERSION = '1.23.1'; ##-- update with perl-reversion from Perl::Version module
 our @ISA = ('PDL::Exporter');
 our @EXPORT_OK =
   (
@@ -78,8 +78,11 @@ offset pointer vector $ptr().
 
 ;#-- emacs
 
-*PDL::ccs_pointerlen = \&ccs_pointerlen;
-sub ccs_pointerlen :lvalue {
+*ccs_pointerlen = \&PDL::ccs_pointerlen; 
+
+##-- now a PDL::PP function in PDL::CCS::Utils
+*PDL::ccs_pointerlen_perl = \&ccs_pointerlen_perl;
+sub ccs_pointerlen_perl :lvalue {
   my ($ptr,$len) = @_;
   if (!defined($len)) {
     $len = $ptr->slice("1:-1") - $ptr->slice("0:-2");
