@@ -10,7 +10,7 @@ use PDL::CCS::IO::Common qw(:intern); ##-- for e.g. _ccsio_write_header, _ccsio_
 use Carp qw(confess);
 use strict;
 
-our $VERSION = '1.23.0';
+our $VERSION = '1.23.1';
 our @ISA = ('PDL::Exporter');
 our @EXPORT_OK =
   (
@@ -37,8 +37,7 @@ PDL::CCS::IO::FITS - PDL::IO::FITS wrappers for PDL::CCS::Nd
  use PDL::CCS::Nd;
  use PDL::CCS::IO::FITS;
 
-
- $ccs = PDL::CCS::Nd->newFromWhich($which,$nnz);
+ $ccs = PDL::CCS::Nd->newFromWhich($which,$nzvals);
 
  ccs_wfits($ccs,$fname);	 # write a pair of FITS files
  $ccs2 = ccs_readfits($fname);   # read a pair of FITS files
