@@ -12,7 +12,7 @@ use PDL::IO::FastRaw;
 use Carp qw(confess);
 use strict;
 
-our $VERSION = '1.23.0';
+our $VERSION = '1.23.1';
 our @ISA = ('PDL::Exporter');
 our @EXPORT_OK = qw(ccs_writefraw ccs_readfraw ccs_mapfraw);
 our %EXPORT_TAGS =
@@ -36,8 +36,7 @@ PDL::CCS::IO::FastRaw - PDL::IO::FastRaw wrappers for PDL::CCS::Nd
  use PDL::CCS::Nd;
  use PDL::CCS::IO::FastRaw;
 
-
- $ccs = PDL::CCS::Nd->newFromWhich($which,$nnz);
+ $ccs = PDL::CCS::Nd->newFromWhich($which,$nzvals);
 
  ccs_writefraw($ccs,$fname);	 # write a pair of raw files
  $ccs2 = ccs_readfraw($fname);   # read a pair of raw files
