@@ -13,7 +13,7 @@ use Fcntl qw(:seek);	   ##-- for rewinding
 use Carp qw(confess);
 use strict;
 
-our $VERSION = '1.23.0';
+our $VERSION = '1.23.1';
 our @ISA = ('PDL::Exporter');
 our @EXPORT_OK =
   (
@@ -39,7 +39,7 @@ PDL::CCS::IO::LDAC - LDA-C format text I/O for PDL::CCS::Nd
  use PDL::CCS::IO::LDAC;
 
  ##-- (Document x Term) matrix
- $dtm = PDL::CCS::Nd->newFromWhich($which,$nnz);
+ $dtm = PDL::CCS::Nd->newFromWhich($which,$nzvals);
  
  ccs_writeldac($dtm,"dtm.ldac");   # write a sparse LDA-C text file
  $dtm2 = ccs_readldac("dtm.ldac"); # read a sparse LDA-C text file
